@@ -16,7 +16,7 @@ from datetime import datetime
 
 
 # Current version number
-__version__ = "0.3.4"
+__version__ = "0.3.5"
 
 
 # Some constants
@@ -324,7 +324,7 @@ def main() -> None:
         settings["name"] = os.path.basename(srcdir)
 
     # show config for debugging
-    if DEBUG_FLAG:
+    if logger.isEnabledFor(logging.DEBUG):
         logger.debug("config loaded:")
         for k, v in sorted(settings.items()):
             logger.debug(f"    {k} = {v}")
@@ -473,9 +473,15 @@ def create_version(version: int, settings: configparser.SectionProxy) -> t.Set[i
                             ):
                                 skip = False
                                 transform = None
-                            elif lline.startswith(ml_open):
-                                skip = not is_ml
-                                transform = transform_func
+                            elif lline.startswith(ml_open) and is_ml:
+                                skip = False
+                                transform = None
+                            elif lline.startswith(ml_open) and not is_ml:
+                                parts = lline.split(maxsplit=3)
+                                if len(parts) > 1:
+                                    skip = not test_version(version, parts[1])
+                                else:
+                                    skip = True
                             elif lline.startswith(tag_open):
                                 parts = lline.split(maxsplit=3)
                                 if len(parts) > 1:
